==> asn1tools-0.17.1.tar.gz: asn1tools-0.17.1/tests/files/bar.py <==
BAR = {'Bar': {'extensibility-implied': False,
         'imports': {},
         'object-classes': {},
         'object-sets': {},
         'tags': 'EXPLICIT',
         'types': {'AcceptTypes': {'members': [{'element': {'size': None,
                                                            'type': 'BIT '
                                                                    'STRING'},
                                                'name': 'standardTypes',
                                                'optional': True,
                                                'size': None,
                                                'tag': {'kind': 'IMPLICIT',
                                                        'number': 0},
                                                'type': 'SEQUENCE OF'},
                                               {'element': {'size': None,
                                                            'type': 'OCTET '
                                                                    'STRING'},
                                                'name': 'otherTypes',
                                                'optional': True,
                                                'size': None,
                                                'tag': {'kind': 'IMPLICIT',
                                                        'number': 1},
                                                'type': 'SEQUENCE OF'}],
                                   'tag': {'class': 'APPLICATION',
                                           'kind': 'IMPLICIT',
                                           'number': 1},
                                   'type': 'SEQUENCE'},
                   'GetRequest': {'members': [{'name': 'headerOnly',
                                               'optional': False,
                                               'type': 'BOOLEAN'},
                                              {'name': 'lock',
                                               'optional': False,
                                               'type': 'BOOLEAN'},
                                              {'name': 'acceptTypes',
                                               'optional': True,
                                               'type': 'AcceptTypes'},
                                              {'name': 'url',
                                               'optional': False,
                                               'size': None,
                                               'type': 'OCTET STRING'}],
                                  'tag': {'class': 'APPLICATION',
                                          'kind': 'IMPLICIT',
                                          'number': 0},
                                  'type': 'SEQUENCE'}},
         'values': {}}}

==> asn1tools-0.45.0.tar.gz: asn1tools-0.45.0/tests/files/bar.py <==
EXPECTED = {'Bar': {'extensibility-implied': False,
         'imports': {},
         'object-classes': {},
         'object-sets': {},
         'tags': 'EXPLICIT',
         'types': {'AcceptTypes': {'members': [{'element': {'type': 'BIT '
                                                                    'STRING'},
                                                'name': 'standardTypes',
                                                'optional': True,
                                                'tag': {'kind': 'IMPLICIT',
                                                        'number': 0},
                                                'type': 'SEQUENCE OF'},
                                               {'element': {'type': 'OCTET '
                                                                    'STRING'},
                                                'name': 'otherTypes',
                                                'optional': True,
                                                'tag': {'kind': 'IMPLICIT',
                                                        'number': 1},
                                                'type': 'SEQUENCE OF'}],
                                   'tag': {'class': 'APPLICATION',
                                           'kind': 'IMPLICIT',
                                           'number': 1},
                                   'type': 'SEQUENCE'},
                   'GetRequest': {'members': [{'name': 'headerOnly',
                                               'type': 'BOOLEAN'},
                                              {'name': 'lock',
                                               'type': 'BOOLEAN'},
                                              {'name': 'acceptTypes',
                                               'optional': True,
                                               'type': 'AcceptTypes'},
                                              {'name': 'url',
                                               'type': 'OCTET STRING'}],
                                  'tag': {'class': 'APPLICATION',
                                          'kind': 'IMPLICIT',
                                          'number': 0},
                                  'type': 'SEQUENCE'}},
         'values': {}}}
